@@ -1,8 +1,6 @@
 /******************************************************************************
  *  bwm-ng handle cmdline and config file options                             *
  *                                                                            *
- *  Copyright (C) 2004-2007 Volker Gropp (bwmng@gropp.org)                    *
- *                                                                            *
  *  for more info read README.                                                *
  *                                                                            *
  *  This program is free software; you can redistribute it and/or modify      *
@@ -337,6 +335,10 @@ void get_cmdln_options(int argc, char *argv[]) {
         pwd_entry=getpwuid(getuid());
         if (pwd_entry!=NULL) {
             str=(char*)malloc(strlen(pwd_entry->pw_dir)+14);
+            if(!str) {
+              printf("Fatal: failed to allocate %zu bytes reading user directory for config file.\n", strlen(pwd_entry->pw_dir)+14);
+              exit(EXIT_FAILURE);
+            }
             snprintf(str,strlen(pwd_entry->pw_dir)+14,"%s/.bwm-ng.conf",pwd_entry->pw_dir);
             read_config(str);
             free(str);
@@ -494,4 +496,3 @@ void get_cmdln_options(int argc, char *argv[]) {
 		output_unit=BYTES_OUT;
     return;
 }
-
